@@ -27,7 +27,8 @@ arma::colvec NormalLogLik(datobjDIAG DatObj, paraDIAG Para, int NKeep) {
 
   //Verbose output
   arma::vec VerboseSeq;
-  VerboseSeq << 0.25 << 0.50 << 0.75;
+  VerboseSeq = {0.25, 0.50, 0.75}; 	// new standard modern C++ brace initialization
+  // VerboseSeq << 0.25 << 0.50 << 0.75;
   VerboseSeq *= NKeep;
 
   //Initialize objects
