@@ -25,7 +25,8 @@ arma::mat YKrigging(Rcpp::List DatObj_List, arma::mat ThetaKrig, int NKeep) {
 
   //Verbose output
   arma::vec VerboseSeq;
-  VerboseSeq << 0.25 << 0.50 << 0.75;
+  VerboseSeq = {0.25, 0.50, 0.75}; 	// new standard modern C++ brace initialization
+  // VerboseSeq << 0.25 << 0.50 << 0.75;
   VerboseSeq *= NKeep;
   Rcpp::Rcout << std::fixed << "Krigging Y: 0%.. ";
 
